package cn.bunny.service.gateway.config;

import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.cors.CorsConfiguration;
import org.springframework.web.cors.reactive.CorsWebFilter;
import org.springframework.web.cors.reactive.UrlBasedCorsConfigurationSource;

@Configuration
@Slf4j
public class CorsConfig {
    /**
     * * 解决跨域
     */
    @Bean
    protected CorsWebFilter addCorsMappings() {
        log.info("CorsConfig===>开始跨域注册表...");

        // 当allowCredentials设置为true时，allowedOrigins属性不能使用通配符"*"，而是需要显式列出允许的源或使用allowedOriginPatterns
        CorsConfiguration config = new CorsConfiguration();
        // 设置跨域请求地址
        // config.addAllowedOrigin("*");
        config.addAllowedMethod("*");
        config.addAllowedHeader("*");
        // 使用allowedOriginPatterns属性：在Spring Framework 5.3及更高版本中，
        // 您可以使用allowedOriginPatterns属性，它允许您使用正则表达式模式来匹配允许的源。这样，您可以更灵活地配置允许的源。例如
        // 使用"https?://example.com"来匹配http://example.com和https://example.com两个源。
        config.addAllowedOriginPattern("*");
        config.setAllowCredentials(true);

        UrlBasedCorsConfigurationSource source = new UrlBasedCorsConfigurationSource();
        source.registerCorsConfiguration("/api/**", config);

        return new CorsWebFilter(source);
    }
}