package cn.bunny.service.web.controller;

import cn.bunny.dto.user.LoginDto;
import cn.bunny.dto.user.RegisterDto;
import cn.bunny.pojo.result.Result;
import cn.bunny.service.web.service.LoginService;
import cn.bunny.vo.system.login.LoginVo;
import cn.bunny.vo.system.login.ValidateCodeVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Tag(name = "登录和注册相关接口")
@RequestMapping("/api")
@RestController
public class LoginController {
    @Autowired
    private LoginService loginService;

    @Operation(summary = "登录接口", description = "前台用户登录接口")
    @PostMapping("login")
    public Result<LoginVo> login(@RequestBody LoginDto loginDto) {
        LoginVo vo = loginService.login(loginDto);
        return Result.success(vo);
    }

    @Operation(summary = "生成验证码", description = "生成验证码")
    @GetMapping("checkCode")
    public Result<ValidateCodeVo> checkCode() {
        ValidateCodeVo vo = loginService.checkCode();
        return Result.success(vo);
    }

    @Operation(summary = "发送邮箱验证码", description = "发送邮箱验证码")
    @PostMapping("sendEmailCode")
    public Result<String> sendEmailCode(String email) {
        loginService.sendEmailCode(email);
        return Result.success();
    }

    @Operation(summary = "注册用户", description = "注册用户")
    @PostMapping("register")
    public Result<RegisterDto> register(@RequestBody RegisterDto registerDto) {
        loginService.register(registerDto);
        return Result.success();
    }

    @Operation(summary = "退出登录", description = "退出登录")
    @PostMapping("logout")
    public Result<String> logout() {
        loginService.logout();
        return Result.success();
    }
}
