package cn.bunny.service.web.service.impl;

import cn.bunny.common.service.context.BaseContext;
import cn.bunny.common.service.exception.BunnyException;
import cn.bunny.common.service.utils.EmptyUtil;
import cn.bunny.dto.user.ResetPwdDto;
import cn.bunny.entity.system.user.User;
import cn.bunny.pojo.result.constant.ExceptionConstant;
import cn.bunny.pojo.result.constant.RedisUserConstant;
import cn.bunny.service.web.mapper.UserMapper;
import cn.bunny.service.web.service.UserService;
import cn.bunny.vo.system.user.UserInfoVo;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;

/**
 * <p>
 * 用户信息 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2024-05-13
 */
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements UserService {
    @Autowired
    private RedisTemplate<String, Object> redisTemplate;
    @Autowired
    private UserMapper userMapper;

    /**
     * 重置密码
     *
     * @param dto 重置密码参数
     */
    @Override
    public void resetPwd(ResetPwdDto dto) {
        String username = dto.getEmail();
        String password = dto.getPassword();
        String emailCode = dto.getEmailCode().toLowerCase();
        Long userId = BaseContext.getUserId();
        String redisEmailCode = (String) redisTemplate.opsForValue().get(RedisUserConstant.getUserEmailCodePrefix(dto.getEmail()));

        // 判断邮箱验证码是否正确
        EmptyUtil.isEmpty(redisEmailCode, ExceptionConstant.PLEASE_SEND_EMAIL_CODE_Exception);
        if (!emailCode.equals(redisEmailCode.toLowerCase()))
            throw new BunnyException(ExceptionConstant.VERIFICATION_CODE_ERROR_Exception);

        // 查询用户信息
        LambdaQueryWrapper<User> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(User::getEmail, username).or().eq(User::getNickName, username);
        User user = getOne(lambdaQueryWrapper);

        // 用户不存在
        if (user == null) throw new BunnyException(ExceptionConstant.USER_NOT_FOUND_Exception);

        user = new User();
        user.setPassword(DigestUtils.md5DigestAsHex(password.getBytes()));
        user.setId(userId);

        // 更新用户
        updateById(user);

        // 删除邮箱验证码
        redisTemplate.delete(RedisUserConstant.getUserEmailCodePrefix(dto.getEmail()));
    }


    /**
     * 获取当前登录用户信息
     *
     * @return 获取用户信息返回参数
     */
    @Override
    public UserInfoVo getCurrentUserInfo() {
        UserInfoVo userInfo = new UserInfoVo();
        User user = getById(BaseContext.getUserId());
        BeanUtils.copyProperties(user, userInfo);

        return userInfo;
    }


    /**
     * 获取登录用户信息
     *
     * @param userId 用户id
     * @return 获取用户信息返回参数
     */
    @Override
    public UserInfoVo getUserInfo(Long userId) {
        UserInfoVo userInfoVo = new UserInfoVo();
        User user = userMapper.selectById(userId);

        if (user == null) throw new BunnyException(ExceptionConstant.USER_NOT_FOUND_Exception);
        BeanUtils.copyProperties(user, userInfoVo);

        return userInfoVo;
    }
}
